@@ -1,8 +1,6 @@
 package main
 
 import (
-	"fmt"
-	"net"
 	"os"
 	"os/exec"
 	"path/filepath"
@@ -15,8 +13,6 @@ import (
 	"github.com/abiosoft/colima/cmd/root"
 	"github.com/abiosoft/colima/config"
 	"github.com/abiosoft/colima/daemon/process/gvproxy"
-	"github.com/abiosoft/colima/daemon/process/vmnet"
-	"github.com/sirupsen/logrus"
 )
 
 func main() {
@@ -35,7 +31,6 @@ func qemuWrapper(qemu string) {
 	}
 
 	gvproxyInfo := gvproxy.Info()
-	vmnetInfo := vmnet.Info()
 
 	// check if qemu is meant to run by lima
 	// decided by -pidfile flag
@@ -48,51 +43,21 @@ func qemuWrapper(qemu string) {
 	}
 
 	args := os.Args[1:] // forward all args
-	var extraFiles []*os.File
 
 	gvproxyEnabled, _ := strconv.ParseBool(os.Getenv(gvproxy.SubProcessEnvVar))
-	vmnetEnabled, _ := strconv.ParseBool(os.Getenv(vmnet.SubProcessEnvVar))
 
 	if qemuRunning && gvproxyEnabled {
-		// vmnet should come first as it would be added by Lima and would have the fd 3
-
-		// vmnet
-		if vmnetEnabled {
-			fd := os.NewFile(3, vmnetInfo.Socket.File())
-			extraFiles = append(extraFiles, fd)
-		}
-
-		// gvproxy
-		{
-			conn, err := net.Dial("unix", gvproxyInfo.Socket.File())
-			if err != nil {
-				logrus.Fatal(fmt.Errorf("error connecting to gvproxy socket: %w", err))
-			}
-			fd, err := conn.(*net.UnixConn).File()
-			if err != nil {
-				logrus.Fatal(fmt.Errorf("error retrieving fd for gvproxy socket: %w", err))
-			}
-			extraFiles = append(extraFiles, fd)
-		}
-
-		// gvproxy fd
-		fd := strconv.Itoa(2 + len(extraFiles))
 		args = append(args,
-			"-netdev", "socket,id=vlan,fd="+fd,
+			"-netdev", "stream,id=vlan,addr.type=unix,addr.path="+gvproxyInfo.Socket.File(),
 			"-device", "virtio-net-pci,netdev=vlan,mac="+gvproxyInfo.MacAddress,
 		)
 	}
 
 	cmd := exec.Command(qemu, args...)
-
 	cmd.Stdout = os.Stdout
 	cmd.Stderr = os.Stderr
 	cmd.Stdin = os.Stdin
 
-	if len(extraFiles) > 0 {
-		cmd.ExtraFiles = append(cmd.ExtraFiles, extraFiles...)
-	}
-
 	err := cmd.Run()
 	if err != nil {
 		if err, ok := err.(*exec.ExitError); ok {
