@@ -20,10 +20,10 @@ type buildArgs struct {
 }
 
 //go:embed Dockerfile
-var dockerfile string
+var dockerfile []byte
 
 //go:embed colima.sh
-var chrootScript string
+var chrootScript []byte
 
 func (u ubuntuRuntime) buildArgs() (b buildArgs, err error) {
 	b.arch = string(u.guest.Arch().Value())
@@ -151,7 +151,9 @@ func (u ubuntuRuntime) createContainer(conf config.Config) error {
 		"--volume", "/:/host",
 
 		// systemd
-		"--mount", "type=bind,source=/sys/fs/cgroup,target=/sys/fs/cgroup",
+		"--mount", "type=tmpfs,destination=/var/lib/journal",
+		"--mount", "type=bind,source=/sys/fs/cgroup/unified,target=/sys/fs/cgroup/unified",
+		"--mount", "type=tmpfs,destination=/sys/fs/cgroup/systemd",
 		"--mount", "type=bind,source=/sys/fs/fuse,target=/sys/fs/fuse",
 		"--mount", "type=bind,source=/tmp/ubuntu,destination=/tmp",
 		"--mount", "type=tmpfs,destination=/run",
