@@ -18,6 +18,7 @@ import (
 	"github.com/abiosoft/colima/config/configmanager"
 	"github.com/abiosoft/colima/daemon"
 	"github.com/abiosoft/colima/daemon/process/gvproxy"
+	"github.com/abiosoft/colima/daemon/process/inotify"
 	"github.com/abiosoft/colima/daemon/process/vmnet"
 	"github.com/abiosoft/colima/environment"
 	"github.com/abiosoft/colima/environment/vm/lima/limautil"
@@ -83,66 +84,85 @@ func (l limaVM) Dependencies() []string {
 }
 
 func (l *limaVM) startDaemon(ctx context.Context, conf config.Config) (context.Context, error) {
+	isQEMU := conf.VMType == QEMU
+	isVZ := conf.VMType == VZ
+
 	// limited to macOS (with Qemu driver)
-	if !util.MacOS() || conf.VMType == VZ {
+	// or vz with inotify enabled
+	if !util.MacOS() || (isVZ && !conf.MountINotify) {
 		return ctx, nil
 	}
 
 	ctxKeyVmnet := daemon.CtxKey(vmnet.Name)
+	ctxKeyInotify := daemon.CtxKey(inotify.Name)
 	ctxKeyGVProxy := daemon.CtxKey(gvproxy.Name)
-	ctxKeyGVProxyHosts := daemon.CtxKey(gvproxy.CtxKeyHosts)
 
 	// use a nested chain for convenience
 	a := l.Init(ctx)
 	log := l.Logger(ctx)
 
-	installedKey := struct{ key string }{key: "installed"}
+	networkInstalledKey := struct{ key string }{key: "network_installed"}
 
-	a.Stage("preparing network")
-	a.Add(func() error {
-		if conf.Network.Driver == gvproxy.Name {
-			ctx = context.WithValue(ctx, ctxKeyGVProxy, true)
-			ctx = context.WithValue(ctx, ctxKeyGVProxyHosts, conf.Network.DNSHosts)
-		}
-		if conf.Network.Address {
-			ctx = context.WithValue(ctx, ctxKeyVmnet, true)
-		}
-		deps, root := l.daemon.Dependencies(ctx)
-		if deps.Installed() {
-			ctx = context.WithValue(ctx, installedKey, true)
+	// add inotify to daemon
+	if conf.MountINotify {
+		a.Add(func() error {
+			ctx = context.WithValue(ctx, ctxKeyInotify, true)
+			deps, _ := l.daemon.Dependencies(ctx, conf)
+			if err := deps.Install(l.host); err != nil {
+				return fmt.Errorf("error setting up inotify dependencies: %w", err)
+			}
 			return nil
-		}
+		})
+	}
 
-		// if user interaction is not required (i.e. root),
-		// no need for another verbose info.
-		if root {
-			log.Println("dependencies missing for setting up reachable IP address")
-			log.Println("sudo password may be required")
-		}
+	// add network processes to daemon
+	if isQEMU {
+		a.Stage("preparing network")
+		a.Add(func() error {
+			if conf.Network.Driver == gvproxy.Name {
+				ctx = context.WithValue(ctx, ctxKeyGVProxy, true)
+			}
+			if conf.Network.Address {
+				ctx = context.WithValue(ctx, ctxKeyVmnet, true)
+			}
+			deps, root := l.daemon.Dependencies(ctx, conf)
+			if deps.Installed() {
+				ctx = context.WithValue(ctx, networkInstalledKey, true)
+				return nil
+			}
 
-		// install deps
-		err := deps.Install(l.host)
-		if err != nil {
-			ctx = context.WithValue(ctx, installedKey, false)
-		}
-		return err
-	})
+			// if user interaction is not required (i.e. root),
+			// no need for another verbose info.
+			if root {
+				log.Println("dependencies missing for setting up reachable IP address")
+				log.Println("sudo password may be required")
+			}
 
+			// install deps
+			err := deps.Install(l.host)
+			if err != nil {
+				ctx = context.WithValue(ctx, networkInstalledKey, false)
+			}
+			return err
+		})
+	}
+
+	// start daemon
 	a.Add(func() error {
-		return l.daemon.Start(ctx)
+		return l.daemon.Start(ctx, conf)
 	})
 
-	// delay to ensure that the vmnet is running
-	statusKey := struct{ key string }{key: "networkStatus"}
-	if conf.Network.Address {
-		a.Retry("", time.Second*3, 5, func(i int) error {
-			s, err := l.daemon.Running(ctx)
+	statusKey := struct{ key string }{key: "daemonStatus"}
+	// delay to ensure that the processes have started
+	if conf.Network.Address || conf.MountINotify {
+		a.Retry("", time.Second*1, 15, func(i int) error {
+			s, err := l.daemon.Running(ctx, conf)
 			ctx = context.WithValue(ctx, statusKey, s)
 			if err != nil {
 				return err
 			}
 			if !s.Running {
-				return fmt.Errorf("network process is not running")
+				return fmt.Errorf("daemon is not running")
 			}
 			for _, p := range s.Processes {
 				if !p.Running {
@@ -155,30 +175,43 @@ func (l *limaVM) startDaemon(ctx context.Context, conf config.Config) (context.C
 
 	// network failure is not fatal
 	if err := a.Exec(); err != nil {
-		func() {
-			installed, _ := ctx.Value(installedKey).(bool)
-			if !installed {
-				log.Warnln(fmt.Errorf("error setting up network dependencies: %w", err))
-				return
-			}
-
-			status, ok := ctx.Value(statusKey).(daemon.Status)
-			if !ok {
-				return
-			}
-			if !status.Running {
-				log.Warnln(fmt.Errorf("error starting network: %w", err))
-				return
-			}
-
-			// revert gvproxy to boolean
-			for _, p := range status.Processes {
-				if !p.Running {
-					ctx = context.WithValue(ctx, daemon.CtxKey(p.Name), false)
-					log.Warnln(fmt.Errorf("error starting %s: %w", p.Name, err))
+		if isQEMU {
+			func() {
+				installed, _ := ctx.Value(networkInstalledKey).(bool)
+				if !installed {
+					log.Warnln(fmt.Errorf("error setting up network dependencies: %w", err))
+					return
 				}
-			}
-		}()
+
+				status, ok := ctx.Value(statusKey).(daemon.Status)
+				if !ok {
+					return
+				}
+				if !status.Running {
+					log.Warnln(fmt.Errorf("error starting network: %w", err))
+					return
+				}
+
+				// revert gvproxy to boolean
+				for _, p := range status.Processes {
+					// TODO: handle inotify separate from network
+					if p.Name == inotify.Name {
+						continue
+					}
+					if !p.Running {
+						ctx = context.WithValue(ctx, daemon.CtxKey(p.Name), false)
+						log.Warnln(fmt.Errorf("error starting %s: %w", p.Name, err))
+					}
+				}
+			}()
+		}
+	}
+
+	// check if inotify is running
+	if conf.MountINotify {
+		if inotifyEnabled, _ := ctx.Value(ctxKeyInotify).(bool); !inotifyEnabled {
+			log.Warnln("error occured enabling inotify daemon")
+		}
 	}
 
 	// preserve vmnet context
@@ -297,8 +330,9 @@ func (l limaVM) Stop(ctx context.Context, force bool) error {
 	a.Stage("stopping")
 
 	if util.MacOS() {
+		conf, _ := limautil.InstanceConfig()
 		a.Retry("", time.Second*1, 10, func(retryCount int) error {
-			err := l.daemon.Stop(ctx)
+			err := l.daemon.Stop(ctx, conf)
 			if err != nil {
 				err = cli.ErrNonFatal(err)
 			}
@@ -320,8 +354,9 @@ func (l limaVM) Teardown(ctx context.Context) error {
 	a := l.Init(ctx)
 
 	if util.MacOS() {
+		conf, _ := limautil.InstanceConfig()
 		a.Retry("", time.Second*1, 10, func(retryCount int) error {
-			return l.daemon.Stop(ctx)
+			return l.daemon.Stop(ctx, conf)
 		})
 	}
 
@@ -478,7 +513,7 @@ func (l limaVM) Set(key, value string) error {
 		return fmt.Errorf("error saving settings: %w", err)
 	}
 
-	if err := l.Write(configFile, string(b)); err != nil {
+	if err := l.Write(configFile, b); err != nil {
 		return fmt.Errorf("error saving settings: %w", err)
 	}
 
