@@ -125,13 +125,16 @@ func ShowSSH(profileID string, layer bool, format string) (resp struct {
 	return resp, nil
 }
 
-func replaceSSHCmd(cmd string, name string, ip string, port int) string {
+func replaceSSHCmd(cmd string, profileID string, ip string, port int) string {
+	profileID = config.Profile(profileID).ID
+	name := config.Profile(profileID).ShortName
 	var out []string
 
 	for _, s := range util.ShellSplit(cmd) {
 		if port > 0 {
 			if strings.HasPrefix(s, "ControlPath=") {
-				s = "ControlPath=" + strconv.Quote(filepath.Join(config.Dir(), "ssh.sock"))
+				configDir := filepath.Join(filepath.Dir(config.Dir()), name)
+				s = "ControlPath=" + strconv.Quote(filepath.Join(configDir, "ssh.sock"))
 			}
 			if strings.HasPrefix(s, "Port=") {
 				s = "Port=" + strconv.Itoa(port)
@@ -144,13 +147,16 @@ func replaceSSHCmd(cmd string, name string, ip string, port int) string {
 		out = append(out, s)
 	}
 
-	if out[len(out)-1] == "lima-"+name {
+	if out[len(out)-1] == "lima-"+profileID {
 		out[len(out)-1] = ip
 	}
 
 	return strings.Join(out, " ")
 }
-func replaceSSHConfig(conf string, name string, ip string, port int) string {
+func replaceSSHConfig(conf string, profileID string, ip string, port int) string {
+	profileID = config.Profile(profileID).ID
+	name := config.Profile(profileID).ShortName
+
 	var out bytes.Buffer
 	scanner := bufio.NewScanner(strings.NewReader(conf))
 
@@ -165,12 +171,13 @@ func replaceSSHConfig(conf string, name string, ip string, port int) string {
 		line := scanner.Text()
 
 		if strings.HasPrefix(line, "Host ") {
-			line = "Host " + name
+			line = "Host " + profileID
 		}
 
 		if port > 0 {
 			if pad, ok := hasPrefix(line, "ControlPath "); ok {
-				line = pad + "ControlPath " + strconv.Quote(filepath.Join(config.Dir(), "ssh.sock"))
+				configDir := filepath.Join(filepath.Dir(config.Dir()), name)
+				line = pad + "ControlPath " + strconv.Quote(filepath.Join(configDir, "ssh.sock"))
 			}
 
 			if pad, ok := hasPrefix(line, "Hostname "); ok {
@@ -214,9 +221,15 @@ func getInstance(profileID string) (InstanceInfo, error) {
 }
 
 // Instances returns Lima instances created by colima.
-func Instances() ([]InstanceInfo, error) {
+func Instances(ids ...string) ([]InstanceInfo, error) {
+	limaIDs := make([]string, len(ids))
+	for i := range ids {
+		limaIDs = append(limaIDs, config.Profile(ids[i]).ID)
+	}
+	args := append([]string{"list", "--json"}, limaIDs...)
+
 	var buf bytes.Buffer
-	cmd := cli.Command("limactl", "list", "--json")
+	cmd := cli.Command("limactl", args...)
 	cmd.Stderr = nil
 	cmd.Stdout = &buf
 
